bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 22. Aventiure
___________________________________________________ #### <Wie si zen Hvnen wart enphangen>
| ### i was Zeizenmûre vntz an den vierden tac ### div molde vf der straze die wile nie gelac ### si enstvbe sam ez brvnne allenthalben dan ### da riten durch oesteriche des kvnic Ecelen man
###### 1277 | ### Do was dem kvnige vil rehte nv geseit ### des im von gedanken swunden siniv leit ### wie herliken Kriemhilt koeme durch div lant ### der kvnich <began> gahen da er die minneclichen vant
###### 1278 | ### Von vil maniger sprache sach man vf den wegen ### vor Ecelen riten manigen kuenen degen ### von kristen vnd von <heiden> manige wite schare ### da si die frovwen funden si chomen herlichen dare
###### 1279 | ### Von Rvzen vnd von Kriechen reit da manich man ### den Polan vnd den Vlachen sach man swinde gan ### ros div vil guoten si mit krefte riten ### swaz si siten heten der wart vil wenic vermiten
###### 1280 | ### Von dem lande ce Kieuen reit da manic degen ### vn– die wilden Pesnære da wart vil gepflegen ### mit bogen schiezen zuo voglen da si flugen ### die phile si sere zuo den wende vaste zvgen
###### 1281 | ### Ein stat bi Tuonowe lit in Osterlant ### div ist geheizen Tulna da wart ir bekant ### vil manic site fremde den si ê nie gesach ### si enphiengen da genuoge den sid vil leit von ir geschach
###### 1282 | ### Vor Ecelen dem kvnige ein ingesinde reit [52b] ### vro vnde vil rike hvbs vn– <gemeit> ### wol vier vnd zweinzek fvrsten rich vn– her ### daz si ir vrowen sahen da von gerten niht mer
###### 1283 | ### Der herzoge Ramvnc vozer Vlachen lant ### mit siben hvndert mannen chom er fur si gerant ### sam vliegende vogele sach man si alle varn ### do kom der furste Gibeke mit vil herlichen scharen
###### 1284 | ### Horboge der snelle wol mit tvsent man ### kerten von dem kvnige gein siner vrowen dan ### vil lute wart geschallet nach des landes siten ### von der Hvnen mage wart ovch da sere geriten
###### 1285 | ### Do kom von Thenemarke der kuone Hawart ### vn– Irinc der vil snelle vor valse wol bewart ### Irnvrit von Dvringen ein wetlicher man ### si enphiengen Kriemhilde daz si eren mvose han
###### 1286 | ### mit zwelfhundert mannen die fuortens in ir schar ### do kom der herre Bloedel mit drin tvseneden dar ### der Ecel bruoder vzer Hvnen lant ### der kom vil herliche da er die kvnniginne vant
###### 1287 | ### Do kom der kvnic Ecele vnd ovch der Dietrich ### mit allen sinen gesellen da was vil loblich ### manic riter edele biderbe vn– guot ### des wart vron Kriemhilde vil wol gehohet ir mvot
###### 1288 | ### Do sprach cer kvniginne der herre Ruediger ### vrowe ich wil enphahen hie den kvnic her ### swen ich iv herre chussen daz sol sin getan ### ian mvget ir niht geliche gruozen alle die Ezelen man
###### 1289 | ### Do huop man von den moeren die kvnniginne her ### Ecel der vil rike enbeite do niht mer ### er stuont von sime rosse mit manigen man ### man sach in vroliche gegen Kriemhilde gan
###### 1290 | ### Zzwene fursten rike als vns da ist geseit ### bi der vrovwen gende truogen rike cleit ### da ir der kvnic Ecele hin engegen gie ### da si den fursten edele mit kvssen gvotlich enphie
###### 1291 | ### Vf ructes ir gebende ir varwe wolgetan ### div lûhte ir vz dem golde da was vil manic man ### si iahen daz vrov Heliche niht schoener kvnde gesin ### dabi so stuont vil nahen des kvniges bruoder Blodelin
###### 1292 | ### Den hiez si kvssen Rvdiger der markgraue rich ### vn– den kvnich Gybeken da stvont ovch her Dietrich ### der reken chvste zwelfe daz Ecelen wip ### do enpfiench si sus mit gruoze maniges riters lip
###### 1293 | ### Al die wile vn– Ecele bi Kriemhilte stuont ### do taten die tvmben als noch die lûte tvont ### vil manigen buneiz richen sach man da geriten ### daz taten cristen helde vnd ovch die heiden nach ir siten
###### 1294 | ### Wie rehte biterlichen die Dietrikes man ### die schefte liezen vliegen mit truonzunen dan ### hohe vber schilte guoter riter hant [53a] ### von den Tiûschen gesten wart durchel maniges schildes rant
###### 1295 | ### Da wart von schefte breken vil michel doz vernomen ### do waren von dem lande die reken alle komen ### do gie der kvnich rike mit vro Kriemhilde dan
###### 1296 | ### Si sahen bi in sten ein vil herlich gezelt ### vol hutten was erfullet alumbe daz velt ### da si solten ruowen nach ir arebeit ### von helden wart gewiset darvnder manic schoene meit
###### 1297 | ### mit der kvnniginne da si sit gesaz ### vf riche stuelgewæte der marcgraue daz ### hete wol geschafet daz man vant vil guot ### daz gesidele Kriemhilt des freut sich Ecelen mvot
###### 1298 | ### Waz do redet Ecele daz ist mir vmbekant ### in der siner zeswen lac ir wiziu hant ### si gesazen minnecliche da Ruediger der degen ### den kvnich niht wolte lazen Criemhilde heimliche phlegen
###### 1299 | ### Do hiez man lan beliben den buhurt vber al ### mit eren wart verendet da der groze schal ### do giengen zuo den hutten die Ecelen man ### man gap in herberge vil witen allenthalben dan
###### 1300 | ### Der tac der hete nv ende si schuofen ir gemach ### vnze man den liehten morgen aber schinen sach ### do was zuo den rossen komen manic man ### hei waz man kvrzewile dem kvnige ze eren began
###### 1301 | ### Der kvnic ez nach den eren die Hvnen schafen bat ### do rite von Tulne ze Wiene zuo der stat ### da fvnden si gecieret vil maniger vrovwen lip ### si enphiengen wol mit eren des kvnigen Ecelen wip
###### 1302 | ### Mit hartem grozem vollen so wart im bereit ### swaz si haben solten vil manich helt gemeit ### sich vreute gen dem schalle herbergen man began ### des kvniges hohgecit huop sich vil frolichen an
###### 1303 | ### Sin mohten niht geherbergen allein der stat ### die niht geste waren Ruediger die bat ### daz si herberge nemen in daz lant ### ich wæne man alle zite bi dem kvnige Kriemhilde vant
###### 1304 | ### Der herre Ditrich vn– ander manic degen ### si heten sich der ruowe mit arbeit bewegen ### durch daz si gesten troesten wolden mvot ### Ruediger vn– sine vrivnde heten churzewile guot
###### 1305 | ### Div hohcit was gevallen an einen phinxtage ### da der kvnich Ecel bi Kriemhilde lac ### in der stat ze Wiene si wene so manigen man ### bi ir ersten manne nie ze dienste gewan
###### 1306 | ### Si chvnde sich mit gabe dem der si nie gesach ### vil maniger darunder zuo den gesten sprach ### wir wanden daz vro Kriemhilt guotes niht mohte han ### nv ist hie mit ir gabe vil manich wunder getan
###### 1307 | ### Div hochcit div werte sibencehen tage [53b] ### ich wene man von deheinem kvnige sage ### des hohcit grozer were daz ist vns gar verdeit ### alle die da waren truogen ir niwe kleit
###### 1308 | ### Si waren in Niderlande da vor nie gesaz ### mit so manigem reken da bi gelovb ich daz ### <was> Sifrit riche des <guotes> daz er nie gewan ### so manigem reken edele so si sach vor Ecelen stan
###### 1309 | ### Ovch gap kvnich nie deheiner zuo sin selber ochgezit ### so manigen richen mantel tief vn– wit ### noch so guoter cleider der si mohten vil han ### die durch <Kriemhilde> willen wurden alle vertan
###### 1310 | ### Ir vrivnde vn– ovch <die> geste heten einen mvot ### daz si da niht ensparten deheiner slahte guot ### swes ieman an si gerte des waren si bereit ### des gestuont do vil der degene von milte bloz ane cleit
###### 1311 | ### Wie si ze Rine seze si gedahte ane daz ### bi ir edelem manne ir ovgen wurden naz ### si hetes vaste hele daz ez ieman kvnde sehen ### ir was nach manigem leide so vil der eren geschehen
###### 1312 | ### Swaz ieman tet mit milte das was gar ein wint ### vnz an Dietriche swaz Botlunges kint ### vn– gegeben hete daz was nv gar verswant ### ovch begie da michel wunder des milten Ruedigeres hant
###### 1313 | ### Vzer Vngerlande der furste Blodelin ### der hiez da lere maken vil manich leitschrin ### von silber vnd von golde da wart hin gegeben ### man sach des kvniges helde so rehte vroliche leben
###### 1314 | ### Werbel vn– Swemlin des kvniges spilman ### ich wen ir iegelicher zer hohcit gewan ### wol ce tvsent marken oder dannoch baz ### da div schoene Criemhilt bi Ecele vnder krone saz
###### 1315 | ### An dem ahtzehenden morgen von Wiene si do riten ### da wart in riterscheften schilde vil versniten ### von speren di da fuorten die reken an der hant ### sus chom der kvnich Ecele vnz in daz Hunische lant
###### 1316 | ### Ze Huniburch der alten si waren vber naht ### do ne kunde niemen wizzen wol des volkes aht ### mit wie getaner krefte si riten vber lant ### hei waz man schoener vrowen in sime heimvote vant
###### 1317 | ### Ze Misenburch der riken da schiften si sich an ### daz wazzer wart verdeket von rossen vn– ovch von man ### alsam ez erbe wære swaz man sin fliezen sach ### die wegmvoden vrovwen die heten semfte vnd ovch gemach
###### 1318 | ### Zesamne was <geslozen> manich schef vil guot ### daz in niht enschadete die vnde noch die fluot ### daruber was gespannen manic guot gezelt ### sam ob si noch beide lant vn– velt
###### 1319 | ### Do komen disiv mere ze Ecelenburch von dan ### do vreuten sich darinne wip vnde man ### des Ecelen ingesinde des ê div vrowe pflac [54a] ### gelebten sit bi Kriemhilte manigen vrolichen tac
###### 1320 | ### Do stuont da wartende vil manic edel meit ### die nach Helken tode heten manige leit ### siben kvnige tohter Criemhilt noch da vant ### von den was gecieret wol allez Ecelen lant
###### 1321 | ### Div iuncvrovwe Herrat noch des gesindes pflac ### div Helchen swester tohter an der vil tvgende lac ### div gemahele Dietriches eins edelens kvniges kint ### div tohter Nentwines div hete vil der eren sint
###### 1322 | ### Gegen der geste chvmfte vreute sich ir mvot ### ovch was dar zuo bereitet vil creftigez guot ### wer kvnde iu daz bescheiden wie sit der kvnich gesaz ### si gelebden da zen Hunen nie mit der kvniginne baz
###### 1323 | ### Do der kvnic mit sime wibe von den staden reit ### wer iegeliche fuorte daz wart do wol geseit ### die edelen Kriemhilte si gruoztens dester baz ### hey wie gewaltechlichen si sit an Helchen stat gesaz
###### 1324 | ### Getrivliches dienstes wart ir vil bekant ### do teilt div kvniginne golt vnd ovch gewant ### silber vn– gesteine swaz si des vber Rin ### mit ir zen Hunen brahte daz muose gar zergeben sin
###### 1325 | ### ovch wurden ir mit dienste sider vndertan ### al des kvniges mage vn– alle sine man ### daz div vrowe Helche nie so gewaltecliche gebot ### so si nv muosen dienen vnz an den Kriemhilte tot
###### 1326 | ### Do stuont mit solhen eren der hof vn– ovch daz lant ### daz man da ze allen ziten die kurzewile vant ### swar nach iegelichem daz herze truoc den mvot ### durch des kvniges liebe vn– der kvnigin guot

<<< Übersicht <<< vorige Seite nächste Seite >>>